@@ -17,22 +17,35 @@
 
 import pygame
 
-class Layer:
-    def __init__(self):
-        self.shapes = []
-
-    def Add(self, shape):
-        self.shapes.append(shape)
-
-    def Render(self, resolution):
-        surface = pygame.Surface(resolution)
-        for s in self.shapes:
-            pygame.draw.polygon(surface, s.color, s.verts)
-
-        return surface
-
 class Polygon:
-    def __init__(self, verts, color):
+    def __init__(self, verts, color, border=0):
         self.type = "POLYGON"
         self.verts = verts
-        self.color = color
\ No newline at end of file
+        self.color = color
+        self.border = border
+
+    def __repr__(self):
+        return f"""StrawberryPy Polygon Shape object:
+Verts: {self.verts}
+Color: {self.color}"""
+
+    def Draw(self, surface):
+        pygame.draw.polygon(surface, self.color, self.verts, self.border)
+
+
+class Circle:
+    def __init__(self, loc, radius, color, border=0):
+        self.type = "CIRCLE"
+        self.loc = loc
+        self.radius = radius
+        self.color = color
+        self.border = border
+
+    def __repr__(self):
+        return f"""StrawberryPy Circle Shape object:
+Location: {self.loc}
+Radius: {self.radius}
+Color: {self.color}"""
+
+    def Draw(self, surface):
+        pygame.draw.circle(surface, self.color, self.loc, self.radius, self.border)
